# color tab

## 颜色标记


<virbit-light style="background: #FFCC00;font-style: normal;font-weight: bold;color: #484848;">高亮</virbit-light>

<virbit-toek style="color: #FA005A;">词语</virbit-toek>

<virbit-question style="border: 1px solid #CCCCCC;background: #FFF8C5;padding: 0px 3px;font-family: Consolas, 微软雅黑;color: #000000;">问题</virbit-question>

<virbit-note style="border: 1px solid #CCCCCC;background: #D9EDF7;padding: 0px 3px;font-family: Consolas, 微软雅黑;color: #3572A5; ">信息</virbit-note>

<virbit-correct style="border: 1px solid #CCCCCC;background: #C6EFCE;padding: 0px 3px;font-family: Consolas, 微软雅黑;color: #006100; ">正确</virbit-correct>

<virbit-error style="border: 1px solid #CCCCCC;background: #FFD2D2;padding: 0px 3px;font-family: Consolas, 微软雅黑;color: #444444;">错误</virbit-error>